@@ -1,7 +1,7 @@
 package Data::Clean::JSON;
 
-our $DATE = '2016-05-21'; # DATE
-our $VERSION = '0.35'; # VERSION
+our $DATE = '2016-05-27'; # DATE
+our $VERSION = '0.36'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,6 +9,12 @@ use warnings;
 
 use parent qw(Data::Clean);
 
+use Exporter qw(import);
+our @EXPORT_OK = qw(
+                       clean_json_in_place
+                       clone_and_clean_json
+               );
+
 sub new {
     my ($class, %opts) = @_;
     $opts{DateTime}  //= [call_method => 'epoch'];
@@ -31,6 +37,14 @@ sub get_cleanser {
     $singleton;
 }
 
+sub clean_json_in_place {
+    __PACKAGE__->get_cleanser->clean_in_place(@_);
+}
+
+sub clone_and_clean_json {
+    __PACKAGE__->get_cleanser->clone_and_clean(@_);
+}
+
 1;
 # ABSTRACT: Clean data so it is safe to output to JSON
 
@@ -46,7 +60,7 @@ Data::Clean::JSON - Clean data so it is safe to output to JSON
 
 =head1 VERSION
 
-This document describes version 0.35 of Data::Clean::JSON (from Perl distribution Data-Clean-JSON), released on 2016-05-21.
+This document describes version 0.36 of Data::Clean::JSON (from Perl distribution Data-Clean-JSON), released on 2016-05-27.
 
 =head1 SYNOPSIS
 
@@ -66,6 +80,16 @@ This document describes version 0.35 of Data::Clean::JSON (from Perl distributio
  use JSON;
  print encode_json($cleaned); # prints '{"code":"CODE","re":"(?^i:abc)"}'
 
+Functional shortcuts:
+
+ use Data::Clean::JSON qw(clean_json_in_place clone_and_clean_json);
+
+ # equivalent to Data::Clean::JSON->get_cleanser->clean_in_place($data)
+ clean_json_in_place($data);
+
+ # equivalent to Data::Clean::JSON->get_cleanser->clone_and_clean($data)
+ $cleaned = clone_and_clean_json($data);
+
 =head1 DESCRIPTION
 
 This class cleans data from anything that might be problematic when encoding to
@@ -110,6 +134,22 @@ L<Log::Any::App>:
  % LOG=1 LOG_CLEANSER_CODE=1 TRACE=1 perl -MLog::Any::App -MData::Clean::JSON \
    -e'$c=Data::Clean::JSON->new; ...'
 
+=head1 FUNCTIONS
+
+None of the functions are exported by default.
+
+=head2 clean_json_in_place($data)
+
+A shortcut for:
+
+ Data::Clean::JSON->get_cleanser->clean_in_place($data)
+
+=head2 clone_and_clean_json($data) => $cleaned
+
+A shortcut for:
+
+ $cleaned = Data::Clean::JSON->get_cleanser->clone_and_clean($data)
+
 =head1 METHODS
 
 =head2 CLASS->get_cleanser => $obj
@@ -187,7 +227,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Clean
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Clean-JSON>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Clean-JSON>.
 
 =head1 BUGS
 
